fit

Function fit 

pub fn fit(
    sw: usize,
    sh: usize,
    dw: usize,
    dh: usize,
) -> (usize, usize, usize, usize)
Largest even-aligned size of sw x sh that fits into dw x dh preserving aspect, and the even-aligned offsets that center it.